window.addEventListener('DOMContentLoaded', function(event){
/* 페이지 안의 이미지 "src" 속성을 "data-src" 속성으로 옮기고 "lazyload" 클래스 부여 */
	const imgs = document.querySelectorAll('img');
	if(imgs.length > 0){
		imgs.forEach(function(img){
			if(img.getAttribute('src') != null){
				img.setAttribute('data-src', img.getAttribute('src'));
				img.setAttribute('src', './img/1x1.png');
			}
			img.classList.add('lazyload');
		});
    }
    
    //"src"를 처리함 이미지 태그에 프로미스 비동기 함수를 매핑
	[...document.querySelectorAll('img.lazyload')].forEach(async img => {
		await onElementVisible(img);
		if(img.getAttribute('data-src') != null){
			img.setAttribute('src', img.getAttribute('data-src'));
		}
    });
});

/* 이미지가 뷰포트 안이면 비동기로 이미지 로딩 */
function onElementVisible(element, options = {}){
	// 기본 교차 옵저버 옵션 설정
	const intersectionObserverOptions = {
		rootMargin: '100px',
		threshold: 0.5,
		...options,
	};

	//이미지가 처음 화면 도큐먼트 뷰포트 영역 안에 표시되면 리졸브 콜백을 실행하는 프로미스 객체를 리턴
	return new Promise(resolve => {
		//옵저버 객체 생성
		const observer = new IntersectionObserver(async entries => {
			// 뷰포트와 교차한 목록
			const [entry] = entries;

			// 도큐먼트 루트와 교차했는지 체크
			if (entry.isIntersecting) {
				// 프로미스 리졸브 실행
				resolve();
				// 옵저버를 종료해 한번만 실행되도록 함
				observer.disconnect();
			}
		}, intersectionObserverOptions);
		observer.observe(element);
	});
}